@@ -116,6 +116,7 @@ __all__ = (
     "ListTypesResponseTypeDef",
     "LogConfigTypeDef",
     "OpenIDConnectConfigTypeDef",
+    "OpenSearchServiceDataSourceConfigTypeDef",
     "PaginatorConfigTypeDef",
     "PipelineConfigTypeDef",
     "RdsHttpEndpointConfigTypeDef",
@@ -320,6 +321,7 @@ _OptionalCreateDataSourceRequestRequestTypeDef = TypedDict(
         "dynamodbConfig": "DynamodbDataSourceConfigTypeDef",
         "lambdaConfig": "LambdaDataSourceConfigTypeDef",
         "elasticsearchConfig": "ElasticsearchDataSourceConfigTypeDef",
+        "openSearchServiceConfig": "OpenSearchServiceDataSourceConfigTypeDef",
         "httpConfig": "HttpDataSourceConfigTypeDef",
         "relationalDatabaseConfig": "RelationalDatabaseDataSourceConfigTypeDef",
     },
@@ -477,6 +479,7 @@ DataSourceTypeDef = TypedDict(
         "dynamodbConfig": "DynamodbDataSourceConfigTypeDef",
         "lambdaConfig": "LambdaDataSourceConfigTypeDef",
         "elasticsearchConfig": "ElasticsearchDataSourceConfigTypeDef",
+        "openSearchServiceConfig": "OpenSearchServiceDataSourceConfigTypeDef",
         "httpConfig": "HttpDataSourceConfigTypeDef",
         "relationalDatabaseConfig": "RelationalDatabaseDataSourceConfigTypeDef",
     },
@@ -1078,6 +1081,14 @@ class OpenIDConnectConfigTypeDef(
     pass
 
 
+OpenSearchServiceDataSourceConfigTypeDef = TypedDict(
+    "OpenSearchServiceDataSourceConfigTypeDef",
+    {
+        "endpoint": str,
+        "awsRegion": str,
+    },
+)
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
@@ -1264,6 +1275,7 @@ _OptionalUpdateDataSourceRequestRequestTypeDef = TypedDict(
         "dynamodbConfig": "DynamodbDataSourceConfigTypeDef",
         "lambdaConfig": "LambdaDataSourceConfigTypeDef",
         "elasticsearchConfig": "ElasticsearchDataSourceConfigTypeDef",
+        "openSearchServiceConfig": "OpenSearchServiceDataSourceConfigTypeDef",
         "httpConfig": "HttpDataSourceConfigTypeDef",
         "relationalDatabaseConfig": "RelationalDatabaseDataSourceConfigTypeDef",
     },
